@@ -14,7 +14,7 @@ from nonebot.permission import SUPERUSER
 from . import approve
 from .utils import At, banSb, init
 from .group_request_verify import verify
-from . import approve, group_request_verify, group_request, notice, utils, word_analyze, r18_pic_ban
+from . import approve, group_request_verify, group_request, notice, utils, word_analyze, r18_pic_ban, auto_ban
 su = nonebot.get_driver().config.superusers
 
 admin_init =  on_command('群管初始化', priority=1, block=True, permission=SUPERUSER | GROUP_ADMIN | GROUP_OWNER)
@@ -378,6 +378,14 @@ __usage__ = """
   记录本群 ： 开始统计聊天记录 permission=GROUP_ADMIN | GROUP_OWNER | SUPERUSER
   停止记录本群 ：停止统计聊天记录
   群词云 ： 发送词云图片
+  
+【被动识别】
+涩图检测：将禁言随机时间
+
+违禁词检测：将禁言随机时间
+群内发送：
+  简单违禁词 ：简单级别过滤
+  严格违禁词 ：严格级别过滤
 """
 __help_plugin_name__ = "简易群管"
 
